[![PyPI version](https://badge.fury.io/py/django-chained-autocomplete.svg)](https://badge.fury.io/py/django-chained-autocomplete)

Django Chained Autocomplete
----------------

Django admin mixins in order to allow autocomplete dropdowns to be chained
(having one dropdown's result dependant on another dropdown's value)


Installation
-----------

Install via pip

    >>> pip install django-chained-autocomplete
    

Add to Django `settings.py`

```python
INSTALLED_APPS = [
    'autocomplete_chained',
    ...
]
```

Usage
-----

TODO
